package
Version:
v0.5.0
Opens a new window with list of versions in this module.
Published: Feb 22, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package config contens the configuration for the application.
type Config struct {
AppID string `env:"APP_ID,required"`
AppSecret string `env:"APP_SECRET,required"`
Email string `env:"EMAIL,required"`
Password string `env:"PASSWORD,required"`
InverterSN string `env:"SN,required"`
}
Config the actual configuration.
Must returns the config or exit 1.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.